import { useEffect, useRef, useState } from "react";
import { sms, userLogin } from "../../api";
import "./index.less";
import { useNavigate } from "react-router-dom";
import { useUserStore } from "../../store/user.store";
import toast from "react-hot-toast";
const defaultForm = {
  user_login: "",
  user_pass: "",
};

const DURATION = 60; // 验证码倒计时

export default function Login() {
  const [loginForm, setLoginForm] = useState(defaultForm);
  let [countdown, setCountdown] = useState(DURATION);
  const timer = useRef<any>();
  const navigate = useNavigate();
  const setUser = useUserStore((s: any) => s.setUser);

  const onClickSmsBtn = () => {
    if (!/^1[3456789]\d{9}$/.test(loginForm.user_login))
      return toast.error("手机号格式有误");
    sms(loginForm.user_login).then((res: any) => {
      if (res?.code === 10000)
        setTimeout(() => {
          toast.success("验证码已发送");
          timer.current = setInterval(() => setCountdown(countdown--), 1000);
        }, 50);
    });
  };

  const onClickLogin = () => {
    userLogin(loginForm).then((res: any) => {
      const { code, data, msg } = res;
      if (code === 10000) {
        console.log(msg);
        navigate(-1);
        setUser(data);
      }
      if (code === 20000) console.error(msg);
    });
  };

  useEffect(() => {
    if (countdown === 0) {
      clearInterval(timer.current);
      setCountdown(DURATION);
    }
  }, [countdown]);

  return (
    <>
      <div className="container login">
        <img src="/favicon.svg" />
        <h4>欢迎，Backset.cn!</h4>
        <div style={{ width: 320 }}>
          <div className="form">
            <input
              style={{ marginTop: "1rem" }}
              type="text"
              className="input"
              placeholder="手机"
              onChange={(e) =>
                setLoginForm((p) => ({
                  ...p,
                  user_login: e.target.value,
                }))
              }
            />
            {/* <input
            style={{ marginTop: "1rem" }}
            className="input"
            type="password"
            onChange={(e) =>
              setLoginForm((p) => ({
                ...p,
                user_pass: e.target.value,
              }))
            }
            onKeyDown={(e) => {
              if (e.key === "Enter") onClickLogin();
            }}
            placeholder="密码"
          /> */}
            <div className="sms-group" style={{ marginTop: "1rem" }}>
              <input
                className="input"
                type="text"
                onKeyDown={(e) => {
                  if (e.key === "Enter") onClickLogin();
                }}
                onChange={(e) =>
                  setLoginForm((p) => ({
                    ...p,
                    user_pass: e.target.value,
                  }))
                }
                placeholder="验证码"
              />
              <span
                className="bs btn ml12 sms-btn br3 outline"
                onClick={onClickSmsBtn}
              >
                {countdown === DURATION ? "获取" : countdown + "s"}
              </span>
            </div>
          </div>
          <button className="submit-btn bs btn" onClick={onClickLogin}>
            进入
          </button>
        </div>
      </div>
      {/* <svg width="100%" viewBox="0 0 1440 690" className="bg">
        <defs>
          <linearGradient id="gradient" x1="0%" y1="50%" x2="100%" y2="50%">
            <stop offset="5%" stop-color="#F78DA7"></stop>
            <stop offset="95%" stop-color="#8ED1FC"></stop>
          </linearGradient>
        </defs>
        <path
          d="M 0,500 C 0,500 0,166 0,166 C 95.69377990430621,161.38755980861242 191.38755980861242,156.77511961722487 291,154 C 390.6124401913876,151.22488038277513 494.1435406698564,150.28708133971293 586,170 C 677.8564593301436,189.71291866028707 758.0382775119618,230.07655502392345 862,216 C 965.9617224880382,201.92344497607655 1093.7033492822968,133.40669856459328 1194,116 C 1294.2966507177032,98.5933014354067 1367.1483253588517,132.29665071770336 1440,166 C 1440,166 1440,500 1440,500 Z"
          stroke="none"
          stroke-width="0"
          fill="url(#gradient)"
          fill-opacity="0.53"
        ></path>
        <defs>
          <linearGradient id="gradient" x1="0%" y1="50%" x2="100%" y2="50%">
            <stop offset="5%" stop-color="#F78DA7"></stop>
            <stop offset="95%" stop-color="#8ED1FC"></stop>
          </linearGradient>
        </defs>
        <path
          d="M 0,500 C 0,500 0,333 0,333 C 110.17224880382773,303.77511961722485 220.34449760765546,274.55023923444975 307,278 C 393.65550239234454,281.44976076555025 456.7942583732058,317.5741626794258 536,320 C 615.2057416267942,322.4258373205742 710.4784688995214,291.1531100478469 825,296 C 939.5215311004786,300.8468899521531 1073.2918660287082,341.8133971291866 1179,354 C 1284.7081339712918,366.1866028708134 1362.3540669856459,349.5933014354067 1440,333 C 1440,333 1440,500 1440,500 Z"
          stroke="none"
          stroke-width="0"
          fill="url(#gradient)"
          fill-opacity="1"
        ></path>
      </svg> */}
    </>
  );
}
